# Drv BMS

Repository that manages the driver for the battery monitoring system that allows to gather measures
from different sensors incorporated to the hardware. This hardware communicates via can.
It will enable to get different data as the hardware admits different types of sensors.

Co-authors:
[Roberto Aldea](https://pypi.org/user/Raldea/), 
[Javier Sanz](https://pypi.org/user/javibu13/),
[Marius Crisan](https://pypi.org/user/mariuscrsn/)
